@@ -15,6 +15,7 @@
 #define BOOST_FILESYSTEM_OPERATIONS_HPP
 
 #include <boost/filesystem/path.hpp>
+#include <boost/detail/scoped_enum_emulation.hpp>
 
 #include <boost/shared_ptr.hpp>
 #include <boost/utility/enable_if.hpp>
@@ -40,6 +41,14 @@
     namespace std { using ::time_t; }
 # endif
 
+//----------------------------------------------------------------------------//
+
+namespace boost
+{
+  namespace filesystem
+  {
+
+// typedef boost::filesystem::path Path; needs to be in namespace boost::filesystem
 # ifndef BOOST_FILESYSTEM_NARROW_ONLY
 #   define BOOST_FS_FUNC(BOOST_FS_TYPE) \
       template<class Path> typename boost::enable_if<is_basic_path<Path>, \
@@ -55,12 +64,6 @@
 #   define BOOST_FS_TYPENAME
 # endif
 
-//----------------------------------------------------------------------------//
-
-namespace boost
-{
-  namespace filesystem
-  {
     template<class Path> class basic_directory_iterator;
 
     // BOOST_FILESYSTEM_NARROW_ONLY needs this:
@@ -121,10 +124,6 @@ namespace boost
 
     namespace detail
     {
-      // singular object used only as a tag; thus initialization and
-      // thread-safety are not issues
-      BOOST_FILESYSTEM_DECL extern system::error_code throws;  
-
       typedef std::pair< system::error_code, bool >
         query_pair;
 
@@ -184,7 +183,7 @@ namespace boost
       BOOST_FILESYSTEM_DECL system::error_code
         rename_api( const std::string & from, const std::string & to );
       BOOST_FILESYSTEM_DECL system::error_code
-        copy_file_api( const std::string & from, const std::string & to );
+        copy_file_api( const std::string & from, const std::string & to, bool fail_if_exists );
 
 #   if defined(BOOST_WINDOWS_API)
       
@@ -228,13 +227,16 @@ namespace boost
       BOOST_FILESYSTEM_DECL system::error_code
         rename_api( const std::wstring & from, const std::wstring & to );
       BOOST_FILESYSTEM_DECL system::error_code
-        copy_file_api( const std::wstring & from, const std::wstring & to );
+        copy_file_api( const std::wstring & from, const std::wstring & to, bool fail_if_exists );
 
 #     endif
 #   endif
 
       template<class Path>
-      unsigned long remove_all_aux( const Path & ph );
+      bool remove_aux( const Path & ph, file_status f );
+
+      template<class Path>
+      unsigned long remove_all_aux( const Path & ph, file_status f );
 
     } // namespace detail
 
@@ -474,19 +476,24 @@ namespace boost
       return ec;
     }
 
-    BOOST_FS_FUNC(void) remove( const Path & ph, system::error_code & ec = detail::throws )
+    BOOST_FS_FUNC(bool) remove( const Path & ph )
     {
-      system::error_code error( detail::remove_api(ph.external_file_string()) );
-      if ( error && &ec == &detail::throws )
+      system::error_code ec;
+      file_status f = symlink_status( ph, ec );
+      if ( ec )
         boost::throw_exception( basic_filesystem_error<Path>(
-          "boost::filesystem::remove", ph, error ) );
-      ec = error;
+          "boost::filesystem::remove", ph, ec ) );
+      return detail::remove_aux( ph, f );
     }
 
     BOOST_FS_FUNC(unsigned long) remove_all( const Path & ph )
     {
-      return exists( ph )|| is_symlink( ph )
-        ? detail::remove_all_aux( ph ) : 0;
+      system::error_code ec;
+      file_status f = symlink_status( ph, ec );
+      if ( ec )
+        boost::throw_exception( basic_filesystem_error<Path>(
+          "boost::filesystem::remove_all", ph, ec ) );
+      return exists( f ) ? detail::remove_all_aux( ph, f ) : 0;
     }
 
     BOOST_FS_FUNC(void) rename( const Path & from_path, const Path & to_path )
@@ -500,11 +507,16 @@ namespace boost
           from_path, to_path, ec ) );
     }
 
-    BOOST_FS_FUNC(void) copy_file( const Path & from_path, const Path & to_path )
+    BOOST_SCOPED_ENUM_START(copy_option)
+      { fail_if_exists, overwrite_if_exists };
+    BOOST_SCOPED_ENUM_END
+
+    BOOST_FS_FUNC(void) copy_file( const Path & from_path, const Path & to_path,
+      BOOST_SCOPED_ENUM(copy_option) option = copy_option::fail_if_exists )
     {
       system::error_code ec( detail::copy_file_api(
         from_path.external_directory_string(),
-        to_path.external_directory_string() ) );
+        to_path.external_directory_string(), option == copy_option::fail_if_exists ) );
       if ( ec )
         boost::throw_exception( basic_filesystem_error<Path>(
           "boost::filesystem::copy_file",
@@ -653,9 +665,9 @@ namespace boost
       { return is_symlink<wpath>( ph ); }
 
     inline bool is_empty( const path & ph )
-      { return is_empty<path>( ph ); }
+      { return boost::filesystem::is_empty<path>( ph ); }
     inline bool is_empty( const wpath & ph )
-      { return is_empty<wpath>( ph ); }
+      { return boost::filesystem::is_empty<wpath>( ph ); }
 
     inline bool equivalent( const path & ph1, const path & ph2 )
       { return equivalent<path>( ph1, ph2 ); }
@@ -712,8 +724,10 @@ namespace boost
       const wpath & from_ph, system::error_code & ec )
       { return create_symlink<wpath>( to_ph, from_ph, ec ); }
 
-    inline void remove( const path & ph )  { remove<path>( ph ); }
-    inline void remove( const wpath & ph ) { remove<wpath>( ph ); }
+    inline bool remove( const path & ph )
+      { return remove<path>( ph ); }
+    inline bool remove( const wpath & ph )
+      { return remove<wpath>( ph ); }
 
     inline unsigned long remove_all( const path & ph )
       { return remove_all<path>( ph ); }
@@ -762,20 +776,39 @@ namespace boost
     namespace detail
     {
       template<class Path>
-      unsigned long remove_all_aux( const Path & ph )
+      bool remove_aux( const Path & ph, file_status f )
+      {
+        if ( exists( f ) )
+        {
+          system::error_code ec = remove_api( ph.external_file_string() );
+          if ( ec )
+            boost::throw_exception( basic_filesystem_error<Path>(
+              "boost::filesystem::remove", ph, ec ) );
+          return true;
+        }
+        return false;
+      }
+
+      template<class Path>
+      unsigned long remove_all_aux( const Path & ph, file_status f )
       {
         static const boost::filesystem::basic_directory_iterator<Path> end_itr;
         unsigned long count = 1;
-        if ( !boost::filesystem::is_symlink( ph ) // don't recurse symbolic links
-          && boost::filesystem::is_directory( ph ) )
+        if ( !boost::filesystem::is_symlink( f ) // don't recurse symbolic links
+          && boost::filesystem::is_directory( f ) )
         {
           for ( boost::filesystem::basic_directory_iterator<Path> itr( ph );
                 itr != end_itr; ++itr )
           {
-            count += remove_all_aux( itr->path() );
+            boost::system::error_code ec;
+            boost::filesystem::file_status fn = boost::filesystem::symlink_status( itr->path(), ec );
+            if ( ec )
+              boost::throw_exception( basic_filesystem_error<Path>( 
+                "boost::filesystem:remove_all", ph, ec ) );
+            count += remove_all_aux( itr->path(), fn );
           }
         }
-        boost::filesystem::remove( ph );
+        remove_aux( ph, f );
         return count;
       }
 
@@ -1020,12 +1053,18 @@ namespace boost
 
       void replace_filename( const string_type & s,
         file_status st, file_status symlink_st )
-     {
-       m_path.remove_filename();
-       m_path /= s;
-       m_status = st;
-       m_symlink_status = symlink_st;
-     }
+      {
+        m_path.remove_filename();
+        m_path /= s;
+        m_status = st;
+        m_symlink_status = symlink_st;
+      }
+
+#   ifndef BOOST_FILESYSTEM_NO_DEPRECATED
+      void replace_leaf( const string_type & s,
+        file_status st, file_status symlink_st )
+          { replace_filename( s, st, symlink_st ); }
+#   endif
 
       const Path &  path() const { return m_path; }
       file_status   status() const;
@@ -1042,6 +1081,10 @@ namespace boost
       {
         return path().filename();
       }
+      typename Path::string_type leaf() const
+      {
+        return path().filename();
+      }
       typename Path::string_type string() const
       {
         return path().string();
