@@ -1,7 +1,7 @@
 /*
  *
  * Copyright (c) 1998-2002
- * Dr John Maddock
+ * John Maddock
  *
  * Use, modification and distribution are subject to the 
  * Boost Software License, Version 1.0. (See accompanying file 
@@ -19,23 +19,19 @@
 
 #define BOOST_REGEX_SOURCE
 
-#include <boost/cregex.hpp>
 #include <boost/regex.hpp>
-#ifndef BOOST_NO_INCLASS_MEMBER_INITIALIZATION
-#  include <boost/integer_traits.hpp>
-#endif
+#include <boost/cregex.hpp>
 #if !defined(BOOST_NO_STD_STRING)
 #include <map>
 #include <list>
-#ifdef BOOST_REGEX_V3
-#include <boost/regex/v3/fileiter.hpp>
-typedef unsigned match_flag_type;
-#else
 #include <boost/regex/v4/fileiter.hpp>
 typedef boost::match_flag_type match_flag_type;
-#endif
 #include <cstdio>
 
+#ifdef BOOST_MSVC
+#pragma warning(disable:4309)
+#endif
+
 namespace boost{
 
 #ifdef __BORLANDC__
@@ -54,7 +50,6 @@ namespace{
 template <class iterator>
 std::string to_string(iterator i, iterator j)
 {
-   BOOST_RE_GUARD_STACK
    std::string s;
    while(i != j)
    {
@@ -108,7 +103,6 @@ public:
 
 void RegExData::update()
 {
-   BOOST_RE_GUARD_STACK
    strings.erase(strings.begin(), strings.end());
    positions.erase(positions.begin(), positions.end());
    if(t == type_pc)
@@ -116,7 +110,7 @@ void RegExData::update()
       for(unsigned int i = 0; i < m.size(); ++i)
       {
          if(m[i].matched) strings[i] = std::string(m[i].first, m[i].second);
-         positions[i] = m[i].matched ? m[i].first - pbase : RegEx::npos;
+         positions[i] = m[i].matched ? m[i].first - pbase : -1;
       }
    }
 #ifndef BOOST_REGEX_NO_FILEITER
@@ -125,7 +119,7 @@ void RegExData::update()
       for(unsigned int i = 0; i < fm.size(); ++i)
       {
          if(fm[i].matched) strings[i] = to_string(fm[i].first, fm[i].second);
-         positions[i] = fm[i].matched ? fm[i].first - fbase : RegEx::npos;
+         positions[i] = fm[i].matched ? fm[i].first - fbase : -1;
       }
    }
 #endif
@@ -134,7 +128,6 @@ void RegExData::update()
 
 void RegExData::clean()
 {
-   BOOST_RE_GUARD_STACK
 #ifndef BOOST_REGEX_NO_FILEITER
    fbase = mapfile::iterator();
    fm = match_results<mapfile::iterator>();
@@ -145,54 +138,46 @@ void RegExData::clean()
 
 RegEx::RegEx()
 {
-   BOOST_RE_GUARD_STACK
    pdata = new re_detail::RegExData();
 }
 
 RegEx::RegEx(const RegEx& o)
 {
-   BOOST_RE_GUARD_STACK
    pdata = new re_detail::RegExData(*(o.pdata));
 }
 
 RegEx::~RegEx()
 {
-   BOOST_RE_GUARD_STACK
    delete pdata;
 }
 
 RegEx::RegEx(const char* c, bool icase)
 {
-   BOOST_RE_GUARD_STACK
    pdata = new re_detail::RegExData();
    SetExpression(c, icase);
 }
 
 RegEx::RegEx(const std::string& s, bool icase)
 {
-   BOOST_RE_GUARD_STACK
    pdata = new re_detail::RegExData();
    SetExpression(s.c_str(), icase);
 }
 
 RegEx& RegEx::operator=(const RegEx& o)
 {
-   BOOST_RE_GUARD_STACK
    *pdata = *(o.pdata);
    return *this;
 }
 
 RegEx& RegEx::operator=(const char* p)
 {
-   BOOST_RE_GUARD_STACK
    SetExpression(p, false);
    return *this;
 }
 
 unsigned int RegEx::SetExpression(const char* p, bool icase)
 {
-   BOOST_RE_GUARD_STACK
-   boost::uint_fast32_t f = icase ? regex::normal | regex::use_except | regex::icase : regex::normal | regex::use_except;
+   boost::uint_fast32_t f = icase ? regex::normal | regex::icase : regex::normal;
    return pdata->e.set_expression(p, f);
 }
 
@@ -204,7 +189,6 @@ unsigned int RegEx::error_code()const
 
 std::string RegEx::Expression()const
 {
-   BOOST_RE_GUARD_STACK
    return pdata->e.expression();
 }
 
@@ -213,7 +197,6 @@ std::string RegEx::Expression()const
 //
 bool RegEx::Match(const char* p, match_flag_type flags)
 {
-   BOOST_RE_GUARD_STACK
    pdata->t = re_detail::RegExData::type_pc;
    pdata->pbase = p;
    const char* end = p;
@@ -229,7 +212,6 @@ bool RegEx::Match(const char* p, match_flag_type flags)
 
 bool RegEx::Search(const char* p, match_flag_type flags)
 {
-   BOOST_RE_GUARD_STACK
    pdata->t = re_detail::RegExData::type_pc;
    pdata->pbase = p;
    const char* end = p;
@@ -257,7 +239,6 @@ struct pred1
 }
 unsigned int RegEx::Grep(GrepCallback cb, const char* p, match_flag_type flags)
 {
-   BOOST_RE_GUARD_STACK
    pdata->t = re_detail::RegExData::type_pc;
    pdata->pbase = p;
    const char* end = p;
@@ -287,7 +268,6 @@ private:
 
 unsigned int RegEx::Grep(std::vector<std::string>& v, const char* p, match_flag_type flags)
 {
-   BOOST_RE_GUARD_STACK
    pdata->t = re_detail::RegExData::type_pc;
    pdata->pbase = p;
    const char* end = p;
@@ -317,7 +297,6 @@ private:
 }
 unsigned int RegEx::Grep(std::vector<std::size_t>& v, const char* p, match_flag_type flags)
 {
-   BOOST_RE_GUARD_STACK
    pdata->t = re_detail::RegExData::type_pc;
    pdata->pbase = p;
    const char* end = p;
@@ -350,24 +329,23 @@ struct pred4
 namespace{
 void BuildFileList(std::list<std::string>* pl, const char* files, bool recurse)
 {
-   BOOST_RE_GUARD_STACK
    file_iterator start(files);
    file_iterator end;
    if(recurse)
    {
       // go through sub directories:
       char buf[MAX_PATH];
-      std::strcpy(buf, start.root());
+      re_detail::overflow_error_if_not_zero(re_detail::strcpy_s(buf, MAX_PATH, start.root()));
       if(*buf == 0)
       {
-         std::strcpy(buf, ".");
-         std::strcat(buf, directory_iterator::separator());
-         std::strcat(buf, "*");
+         re_detail::overflow_error_if_not_zero(re_detail::strcpy_s(buf, MAX_PATH, "."));
+         re_detail::overflow_error_if_not_zero(re_detail::strcat_s(buf, MAX_PATH, directory_iterator::separator()));
+         re_detail::overflow_error_if_not_zero(re_detail::strcat_s(buf, MAX_PATH, "*"));
       }
       else
       {
-         std::strcat(buf, directory_iterator::separator());
-         std::strcat(buf, "*");
+         re_detail::overflow_error_if_not_zero(re_detail::strcat_s(buf, MAX_PATH, directory_iterator::separator()));
+         re_detail::overflow_error_if_not_zero(re_detail::strcat_s(buf, MAX_PATH, "*"));
       }
       directory_iterator dstart(buf);
       directory_iterator dend;
@@ -380,7 +358,11 @@ void BuildFileList(std::list<std::string>* pl, const char* files, bool recurse)
 
       while(dstart != dend)
       {
-         std::sprintf(buf, "%s%s%s", dstart.path(), directory_iterator::separator(), ptr);
+#if BOOST_WORKAROUND(BOOST_MSVC, >= 1400) && !defined(_WIN32_WCE) && !defined(UNDER_CE)
+         (::sprintf_s)(buf, sizeof(buf), "%s%s%s", dstart.path(), directory_iterator::separator(), ptr);
+#else
+         (std::sprintf)(buf, "%s%s%s", dstart.path(), directory_iterator::separator(), ptr);
+#endif
          BuildFileList(pl, buf, recurse);
          ++dstart;
       }
@@ -395,7 +377,6 @@ void BuildFileList(std::list<std::string>* pl, const char* files, bool recurse)
 
 unsigned int RegEx::GrepFiles(GrepFileCallback cb, const char* files, bool recurse, match_flag_type flags)
 {
-   BOOST_RE_GUARD_STACK
    unsigned int result = 0;
    std::list<std::string> file_list;
    BuildFileList(&file_list, files, recurse);
@@ -423,7 +404,6 @@ unsigned int RegEx::GrepFiles(GrepFileCallback cb, const char* files, bool recur
 
 unsigned int RegEx::FindFiles(FindFilesCallback cb, const char* files, bool recurse, match_flag_type flags)
 {
-   BOOST_RE_GUARD_STACK
    unsigned int result = 0;
    std::list<std::string> file_list;
    BuildFileList(&file_list, files, recurse);
@@ -491,7 +471,6 @@ std::size_t RegEx::Split(std::vector<std::string>& v,
 //
 std::size_t RegEx::Position(int i)const
 {
-   BOOST_RE_GUARD_STACK
    switch(pdata->t)
    {
    case re_detail::RegExData::type_pc:
@@ -511,16 +490,14 @@ std::size_t RegEx::Position(int i)const
    return RegEx::npos;
 }
 
-unsigned int RegEx::Marks()const
+std::size_t RegEx::Marks()const
 {
-   BOOST_RE_GUARD_STACK
    return pdata->e.mark_count();
 }
 
 
 std::size_t RegEx::Length(int i)const
 {
-   BOOST_RE_GUARD_STACK
    switch(pdata->t)
    {
    case re_detail::RegExData::type_pc:
@@ -542,7 +519,6 @@ std::size_t RegEx::Length(int i)const
 
 bool RegEx::Matched(int i)const
 {
-   BOOST_RE_GUARD_STACK
    switch(pdata->t)
    {
    case re_detail::RegExData::type_pc:
@@ -565,7 +541,6 @@ bool RegEx::Matched(int i)const
 
 std::string RegEx::What(int i)const
 {
-   BOOST_RE_GUARD_STACK
    std::string result;
    switch(pdata->t)
    {
@@ -588,14 +563,10 @@ std::string RegEx::What(int i)const
    return result;
 }
 
-#ifndef __MINGW32__
-#ifndef BOOST_NO_INCLASS_MEMBER_INITIALIZATION
-const std::size_t RegEx::npos = ::boost::integer_traits<std::size_t>::const_max;
-#elif defined(BOOST_HAS_LONG_LONG)
-const std::size_t RegEx::npos = ~0ULL;
+#ifdef BOOST_HAS_LONG_LONG
+const std::size_t RegEx::npos = static_cast<std::size_t>(~0ULL);
 #else
-const std::size_t RegEx::npos = ~0UL;
-#endif
+const std::size_t RegEx::npos = static_cast<std::size_t>(~0UL);
 #endif
 
 } // namespace boost
@@ -612,7 +583,7 @@ const std::size_t RegEx::npos = ~0UL;
 //
 namespace std{
 template<> template<>
-basic_string<char>&
+basic_string<char>& BOOST_REGEX_DECL
 basic_string<char>::replace<const char*>(char* f1, char* f2, const char* i1, const char* i2)
 {
    unsigned insert_pos = f1 - begin();
@@ -633,7 +604,29 @@ basic_string<char>::replace<const char*>(char* f1, char* f2, const char* i1, con
    }
    return *this;
 }
+template<> template<>
+basic_string<wchar_t>& BOOST_REGEX_DECL
+basic_string<wchar_t>::replace<const wchar_t*>(wchar_t* f1, wchar_t* f2, const wchar_t* i1, const wchar_t* i2)
+{
+   unsigned insert_pos = f1 - begin();
+   unsigned remove_len = f2 - f1;
+   unsigned insert_len = i2 - i1;
+   unsigned org_size = size();
+   if(insert_len > remove_len)
+   {
+      append(insert_len-remove_len, ' ');
+      std::copy_backward(begin() + insert_pos + remove_len, begin() + org_size, end());
+      std::copy(i1, i2, begin() + insert_pos);
+   }
+   else
+   {
+      std::copy(begin() + insert_pos + remove_len, begin() + org_size, begin() + insert_pos + insert_len);
+      std::copy(i1, i2, begin() + insert_pos);
+      erase(size() + insert_len - remove_len);
+   }
+   return *this;
 }
+} // namespace std
 #endif
 
 #endif
@@ -652,3 +645,4 @@ basic_string<char>::replace<const char*>(char* f1, char* f2, const char* i1, con
 
 
 
+
