@@ -3,6 +3,9 @@ from SCons.Util import Split
 TOP_extra_files = Split('''
     ABOUT-NLS
     ANNOUNCE
+    autogen.sh
+    config.log
+    configure.ac
     COPYING
     INSTALL
     INSTALL.MacOSX
@@ -10,6 +13,7 @@ TOP_extra_files = Split('''
     INSTALL.autoconf
     INSTALL.cmake
     INSTALL.scons
+    lyx.1in
     Makefile.am
     NEWS
     README
@@ -17,13 +21,9 @@ TOP_extra_files = Split('''
     README.Win32
     README.localization
     RELEASE-NOTES
-    UPGRADING
-    autogen.sh
-    config.log
-    configure.ac
-    lyx.1in
     rename.sh
     scons_lyx.log
+    UPGRADING
 ''')
 
 
@@ -44,6 +44,7 @@ src_header_files = Split('''
     Citation.h
     CmdDef.h
     Color.h
+    ColorSet.h
     ColorCode.h
     CompletionList.h
     Converter.h
@@ -146,6 +147,7 @@ src_pre_files = Split('''
     BufferList.cpp
     BufferParams.cpp
     BufferView.cpp
+    buffer_funcs.cpp
     Bullet.cpp
     Changes.cpp
     Chktex.cpp
@@ -163,6 +165,7 @@ src_pre_files = Split('''
     Encoding.cpp
     ErrorList.cpp
     Exporter.cpp
+    factory.cpp
     FloatList.cpp
     Floating.cpp
     Font.cpp
@@ -183,24 +186,33 @@ src_pre_files = Split('''
     Layout.cpp
     LayoutFile.cpp
     Length.cpp
+    lengthcommon.cpp
     Lexer.cpp
     LyX.cpp
     LyXAction.cpp
+    lyxfind.cpp
     LyXFunc.cpp
     LyXRC.cpp
     LyXVC.cpp
     MetricsInfo.cpp
     Mover.cpp
+    output.cpp
     OutputParams.cpp
+    output_docbook.cpp
+    output_latex.cpp
+    output_plaintext.cpp
+    paragraph_funcs.cpp
     PDFOptions.cpp
     ParIterator.cpp
     Paragraph.cpp
     ParagraphMetrics.cpp
     ParagraphParameters.cpp
     Row.cpp
+    rowpainter.cpp
     Server.cpp
     ServerSocket.cpp
     Session.cpp
+    sgml.cpp
     Spacing.cpp
     TexRow.cpp
     Text.cpp
@@ -212,42 +224,31 @@ src_pre_files = Split('''
     Trans.cpp
     Undo.cpp
     VCBackend.cpp
-    VSpace.cpp
-    buffer_funcs.cpp
-    factory.cpp
-    lengthcommon.cpp
-    lyxfind.cpp
-    output.cpp
-    output_docbook.cpp
-    output_latex.cpp
-    output_plaintext.cpp
-    paragraph_funcs.cpp
-    rowpainter.cpp
-    sgml.cpp
     version.cpp
+    VSpace.cpp
     WordList.cpp
 ''')
 
 
 src_post_files = Split('''
     BiblioInfo.cpp
+    boost.cpp
     Box.cpp
     Dimension.cpp
     ModuleList.cpp
     PrinterParams.cpp
     SpellBase.cpp
     Thesaurus.cpp
-    boost.cpp
 ''')
 
 
 src_extra_src_files = Split('''
     ASpell.cpp
     ISpell.cpp
+    main.cpp
     PSpell.cpp
     Section.cpp
     Variables.cpp
-    main.cpp
 ''')
 
 
@@ -263,34 +264,21 @@ src_client_header_files = Split('''
 
 
 src_client_files = Split('''
-    Messages.cpp
     boost.cpp
     client.cpp
     gettext.cpp
+    Messages.cpp
 ''')
 
 
 src_client_extra_files = Split('''
+    lyxclient.1in
     Makefile.am
-    lyxclient.man
     pch.h
 ''')
 
 
 src_support_header_files = Split('''
-    ExceptionMessage.h
-    FileMonitor.h
-    FileName.h
-    ForkedCalls.h
-    Messages.h
-    Package.h
-    Path.h
-    RandomAccessList.h
-    SignalSlot.h
-    SignalSlotPrivate.h
-    Systemcall.h
-    Timeout.h
-    Translator.h
     convert.h
     copied_ptr.h
     debug.h
@@ -298,8 +286,12 @@ src_support_header_files = Split('''
     docstring.h
     docstring_list.h
     environment.h
+    ExceptionMessage.h
+    FileMonitor.h
+    FileName.h
     filetools.h
     foreach.h
+    ForkedCalls.h
     gettext.h
     gzstream.h
     lassert.h
@@ -308,11 +300,20 @@ src_support_header_files = Split('''
     lyxalgo.h
     lyxlib.h
     lyxtime.h
+    Messages.h
     os.h
     os_win32.h
+    Package.h
+    Path.h
     qstring_helpers.h
+    RandomAccessList.h
+    SignalSlot.h
+    SignalSlotPrivate.h
     socktools.h
+    Systemcall.h
     textutils.h
+    Timeout.h
+    Translator.h
     types.h
     unicode.h
     userinfo.h
@@ -320,31 +321,31 @@ src_support_header_files = Split('''
 
 
 src_support_files = Split('''
-    FileMonitor.cpp
-    FileName.cpp
-    ForkedCalls.cpp
-    Messages.cpp
-    Package.cpp
-    Path.cpp
-    SignalSlot.cpp
-    SignalSlotPrivate.cpp
-    Systemcall.cpp
-    Timeout.cpp
     convert.cpp
     debug.cpp
     docstream.cpp
     docstring.cpp
     environment.cpp
+    FileMonitor.cpp
+    FileName.cpp
     filetools.cpp
+    ForkedCalls.cpp
     gettext.cpp
     gzstream.cpp
     kill.cpp
     lassert.cpp
     lstrings.cpp
     lyxtime.cpp
+    Messages.cpp
     os.cpp
+    Package.cpp
+    Path.cpp
     qstring_helpers.cpp
+    SignalSlot.cpp
+    SignalSlotPrivate.cpp
     socktools.cpp
+    Systemcall.cpp
+    Timeout.cpp
     unicode.cpp
     userinfo.cpp
 ''')
@@ -587,12 +588,12 @@ src_tex2lyx_header_files = Split('''
 
 
 src_tex2lyx_files = Split('''
+    boost.cpp
     Context.cpp
     Font.cpp
-    Parser.cpp
-    boost.cpp
     gettext.cpp
     math.cpp
+    Parser.cpp
     preamble.cpp
     table.cpp
     tex2lyx.cpp
@@ -608,13 +609,14 @@ src_tex2lyx_copied_header_files = Split('''
 src_tex2lyx_copied_files = Split('''
     Color.cpp
     Counters.cpp
+    Encoding.cpp
     FloatList.cpp
     Floating.cpp
     Layout.cpp
+    lengthcommon.cpp
     Lexer.cpp
     TextClass.cpp
     insets/InsetLayout.cpp
-    lengthcommon.cpp
 ''')
 
 
@@ -624,7 +626,7 @@ src_tex2lyx_extra_files = Split('''
     test-insets.tex
     test-structure.tex
     test.ltx
-    tex2lyx.1
+    tex2lyx.1in
     test/box-color-size-space-align.tex
     test/DummyDocument.tex
     test/foo.eps
@@ -636,6 +638,7 @@ src_tex2lyx_extra_files = Split('''
 
 
 src_frontends_header_files = Split('''
+    alert.h
     Application.h
     Clipboard.h
     FontLoader.h
@@ -643,12 +646,11 @@ src_frontends_header_files = Split('''
     KeyModifier.h
     KeySymbol.h
     LyXView.h
+    mouse_state.h
     Painter.h
     Selection.h
     WorkArea.h
     WorkAreaManager.h
-    alert.h
-    mouse_state.h
 ''')
 
 
@@ -766,12 +768,12 @@ src_frontends_qt4_header_files = Split('''
     LyXFileDialog.h
     Menus.h
     PanelStack.h
+    qt_helpers.h
+    qt_i18n.h
     TocModel.h
     TocWidget.h
     Toolbars.h
     Validator.h
-    qt_helpers.h
-    qt_i18n.h
 ''')
 
 
@@ -856,19 +858,19 @@ src_frontends_qt4_files = Split('''
     LyXFileDialog.cpp
     Menus.cpp
     PanelStack.cpp
+    qt_helpers.cpp
     TocModel.cpp
     TocWidget.cpp
     Toolbars.cpp
     Validator.cpp
-    qt_helpers.cpp
 ''')
 
 
 src_frontends_qt4_extra_files = Split('''
     GuiFontMetrics.h
     Makefile.am
-    README
     pch.h
+    README    
 ''')
 
 
@@ -948,6 +950,7 @@ src_frontends_qt4_ui_files = Split('''
     TextLayoutUi.ui
     ThesaurusUi.ui
     TocUi.ui
+    ToggleWarningUi.ui
     VSpaceUi.ui
     ViewSourceUi.ui
     WrapUi.ui
@@ -955,8 +958,8 @@ src_frontends_qt4_ui_files = Split('''
 
 
 src_frontends_qt4_ui_extra_files = Split('''
-    Makefile.am
     compile_uic.sh
+    Makefile.am    
 ''')
 
 
@@ -1122,7 +1125,6 @@ intl_files = Split('''
 
 
 intl_extra_files = Split('''
-    VERSION
     config.charset
     libgnuintl.h.in
     locale.alias
@@ -1133,11 +1135,11 @@ intl_extra_files = Split('''
     ref-add.sin
     ref-del.sin
     vasnprintf.c
+    VERSION
 ''')
 
 
 config_extra_files = Split('''
-    Makefile.am
     common.am
     config.guess
     config.rpath
@@ -1147,6 +1149,7 @@ config_extra_files = Split('''
     libtool.m4
     ltmain.sh
     lyxinclude.m4
+    Makefile.am
     missing
     mkinstalldirs
     pkg.m4
@@ -1163,12 +1166,6 @@ sourcedoc_extra_files = Split('''
 
 
 po_extra_files = Split('''
-    LINGUAS
-    Makefile.in.in
-    Makevars
-    POTFILES.in
-    README
-    Rules-quot
     ar.po
     bg.po
     boldquot.sed
@@ -1187,21 +1184,28 @@ po_extra_files = Split('''
     he.po
     hu.po
     insert-header.sin
+    id.po
     it.po
     ja.po
     ko.po
+    LINGUAS
     lyx_pot.py
+    Makefile.in.in
+    Makevars
     nb.po
     nl.po
     nn.po
     pl.po
     pocheck.pl
+    POTFILES.in
     postats.sh
     pt.po
     quot.sed
+    README
     remove-potcdate.sin
     ro.po
     ru.po
+    Rules-quot
     sk.po
     sl.po
     sv.po
@@ -1214,9 +1218,9 @@ po_extra_files = Split('''
 
 
 lib_files = Split('''
-    CREDITS
     chkconfig.ltx
     configure.py
+    CREDITS
     encodings
     external_templates
     languages
@@ -1227,10 +1231,10 @@ lib_files = Split('''
 
 
 lib_extra_files = Split('''
-    Makefile.am
     autocorrect
     build-listerrors
     generate_contributions.py
+    Makefile.am
 ''')
 
 
@@ -1307,6 +1311,11 @@ lib_templates_files = Split('''
     revtex.lyx
     revtex4.lyx
     slides.lyx
+    svjour3.lyx
+    svmono_book.lyx
+    svmult_appendix.lyx
+    svmult_author.lyx
+    svmult_editor.lyx
 ''')
 
 
@@ -1321,7 +1330,6 @@ lib_ui_files = Split('''
 
 lib_fonts_files = Split('''
     BaKoMaFontLicense.txt
-    ReadmeBaKoMa4LyX.txt
     cmex10.ttf
     cmmi10.ttf
     cmr10.ttf
@@ -1330,6 +1338,7 @@ lib_fonts_files = Split('''
     eufm10.ttf
     msam10.ttf
     msbm10.ttf
+    ReadmeBaKoMa4LyX.txt
     wasy10.ttf
 ''')
 
@@ -1340,6 +1349,7 @@ lib_images_files = Split('''
     amssymb.png
     banner.png
     bookmark-goto.png
+    bookmark-goto_0.png
     bookmark-save.png
     box-insert.png
     break-line.png
@@ -1384,6 +1394,7 @@ lib_images_files = Split('''
     dialog-show_mathmatrix.png
     dialog-show_print.png
     dialog-show_spellchecker.png
+    dialog-show_vclog.png
     dialog-toggle_toc.png
     down.png
     ert-insert.png
@@ -1412,11 +1423,6 @@ lib_images_files = Split('''
     layout_Section.png
     lyx-quit.png
     lyx.png
-    vc-check-in.png
-    vc-check-out.png
-    dialog-show_vclog.png
-    vc-register.png
-    vc-revert.png
     marginalnote-insert.png
     math-display.png
     math-macro-add-greedy-optional-param.png
@@ -1447,9 +1453,9 @@ lib_images_files = Split('''
     split-view_horizontal.png
     split-view_vertical.png
     standard.png
-    tabular-feature_align-center.png
-    tabular-feature_align-left.png
-    tabular-feature_align-right.png
+    tabular-feature_m-align-center.png
+    tabular-feature_m-align-left.png
+    tabular-feature_m-align-right.png
     tabular-feature_append-column.png
     tabular-feature_append-row.png
     tabular-feature_delete-column.png
@@ -1467,9 +1473,9 @@ lib_images_files = Split('''
     tabular-feature_toggle-rotate-cell.png
     tabular-feature_toggle-rotate-tabular.png
     tabular-feature_unset-all-lines.png
-    tabular-feature_valign-bottom.png
-    tabular-feature_valign-middle.png
-    tabular-feature_valign-top.png
+    tabular-feature_m-valign-bottom.png
+    tabular-feature_m-valign-middle.png
+    tabular-feature_m-valign-top.png
     tabular-insert.png
     thesaurus-entry.png
     toolbar-toggle_math.png
@@ -1479,26 +1485,22 @@ lib_images_files = Split('''
     unknown.png
     up.png
     url-insert.png
+    vc-check-in.png
+    vc-check-out.png
+    vc-locking-toggle.png
+    vc-register.png
+    vc-repo-update.png
+    vc-revert.png
 ''')
 
 
 lib_images_extra_files = Split('''
-    README
     font-smallcaps.png
+    README
 ''')
 
 
 lib_images_math_files = Split('''
-    Bbbk.png
-    Finv.png
-    Game.png
-    Im.png
-    Lleftarrow.png
-    Lsh.png
-    Re.png
-    Rrightarrow.png
-    Rsh.png
-    Vvdash.png
     acute.png
     aleph.png
     alpha.png
@@ -1515,6 +1517,7 @@ lib_images_math_files = Split('''
     bar.png
     bars.png
     barwedge.png
+    Bbbk.png
     because.png
     beta.png
     beth.png
@@ -1619,6 +1622,9 @@ lib_images_math_files = Split('''
     eth.png
     exists.png
     fallingdotseq.png
+    fint.png
+    fintop.png
+    Finv.png
     flat.png
     font.png
     forall.png
@@ -1626,6 +1632,7 @@ lib_images_math_files = Split('''
     frac.png
     frown.png
     functions.png
+    Game.png
     gamma.png
     gamma2.png
     geq.png
@@ -1659,6 +1666,7 @@ lib_images_math_files = Split('''
     iiintop.png
     iint.png
     iintop.png
+    Im.png
     imath.png
     in.png
     infty.png
@@ -1670,6 +1678,10 @@ lib_images_math_files = Split('''
     kappa.png
     lambda.png
     lambda2.png
+    landdownint.png
+    landdownintop.png
+    landupint.png
+    landupintop.png
     langle.png
     lbrace.png
     lbrace_rbrace.png
@@ -1703,6 +1715,7 @@ lib_images_math_files = Split('''
     lfloor_rfloor.png
     ll.png
     llcorner.png
+    Lleftarrow.png
     lll.png
     lnapprox.png
     lneq.png
@@ -1721,6 +1734,7 @@ lib_images_math_files = Split('''
     lparen.png
     lparen_rparen.png
     lrcorner.png
+    Lsh.png
     ltimes.png
     lvertneqq.png
     mapsto.png
@@ -1835,6 +1849,7 @@ lib_images_math_files = Split('''
     rbrace.png
     rbracket.png
     rceil.png
+    Re.png
     rfloor.png
     rho.png
     rightarrow.png
@@ -1850,6 +1865,8 @@ lib_images_math_files = Split('''
     risingdotseq.png
     root.png
     rparen.png
+    Rrightarrow.png
+    Rsh.png
     rtimes.png
     searrow.png
     setminus.png
@@ -1973,6 +1990,7 @@ lib_images_math_files = Split('''
     vert.png
     vert2.png
     vphantom.png
+    Vvdash.png
     wedge.png
     widehat.png
     widetilde.png
@@ -2027,7 +2045,6 @@ lib_tex_files = Split('''
 
 lib_doc_files = Split('''
     Customization.lyx
-    DocStyle.lyx
     DummyDocument1.lyx
     DummyDocument2.lyx
     DummyTextDocument.txt
@@ -2056,20 +2073,17 @@ lib_doc_clipart_files = Split('''
     ChangesToolbar.png
     ChildDocumentQt4.png
     CommentNoteImageQt4.png
+    endnotes.pdf
     ERT.png
+    escher-lsd.eps
     ExternalMaterialQt4.png
     ExtraToolbar.png
-    GreyedOutNoteImageQt4.png
-    LaTeX.png
-    LyXNoteImageQt4.png
-    SpaceMarker.png
-    StandardToolbar.png
-    ToolbarEnvBox.png
-    endnotes.pdf
-    escher-lsd.eps
     floatQt4.png
     footnoteQt4.png
+    GreyedOutNoteImageQt4.png
     labelQt4.png
+    LaTeX.png
+    LyXNoteImageQt4.png
     macrobox.png
     MacroToolbar.png
     macrouse.png
@@ -2077,6 +2091,9 @@ lib_doc_clipart_files = Split('''
     mobius.eps
     platypus.eps
     referenceQt4.png
+    SpaceMarker.png
+    StandardToolbar.png
+    ToolbarEnvBox.png
     ViewToolbar.png
     with_fntright.pdf
     without_fntright.pdf
@@ -2155,16 +2172,16 @@ lib_doc_es_clipart_files = Split('''
     ComentNotaImagenQt4.png
     CuadroMinipagQt4.png
     DocumentoHijoQt4.png
-    GrisNotaImagenQt4.png
-    MaterialExternoQt4.png
-    NotaLyXImagenQt4.png
-    Resumen.pdf
     es_ERT.png
     es_ToolbarEnvBox.png
     etiquetaQt4.png
     flotanteQt4.png
+    GrisNotaImagenQt4.png
+    MaterialExternoQt4.png
+    NotaLyXImagenQt4.png
     notapieQt4.png
     referenciaQt4.png
+    Resumen.pdf
 ''')
 
 
@@ -2187,6 +2204,7 @@ lib_doc_fr_files = Split('''
     Formula-numbering.lyx
     Intro.lyx
     Math.lyx
+    Shortcuts.lyx
     Tutorial.lyx
     UserGuide.lyx
 ''')
@@ -2196,11 +2214,11 @@ lib_doc_fr_clipart_files = Split('''
     BoxInsetDefaultQt4.png
     ChildDocumentQt4.png
     CommentNoteImageQt4.png
-    GreyedOutNoteImageQt4.png
-    LyXNoteImageQt4.png
     floatQt4.png
     footnoteQt4.png
+    GreyedOutNoteImageQt4.png
     labelQt4.png
+    LyXNoteImageQt4.png    
 ''')
 
 
@@ -2222,6 +2240,19 @@ lib_doc_hu_files = Split('''
 ''')
 
 
+lib_doc_id_files = Split('''
+    Intro.lyx
+    Tutorial.lyx
+''')
+
+
+lib_doc_id_clipart_files = Split('''
+    id-contrib.png
+    id-footnote.png
+    id-lingkungan.png
+''')
+
+
 lib_doc_it_files = Split('''
     Customization.lyx
     Intro.lyx
@@ -2240,6 +2271,7 @@ lib_doc_ja_files = Split('''
     Extended.lyx
     Intro.lyx
     LaTeXConfig.lyx
+    Math.lyx
     Shortcuts.lyx
     Tutorial.lyx
     UserGuide.lyx
@@ -2297,6 +2329,7 @@ lib_doc_sl_files = Split('''
 
 
 lib_doc_sk_files = Split('''
+    Intro.lyx
     Tutorial.lyx
     UserGuide.lyx
 ''')
@@ -2318,6 +2351,12 @@ lib_doc_uk_clipart_files = Split('''
 ''')
 
 
+lib_doc_zhCN_files = Split('''
+    Intro.lyx
+    Tutorial.lyx
+''')
+
+
 lib_examples_files = Split('''
     aa_sample.lyx
     aas_sample.lyx
@@ -2369,6 +2408,8 @@ lib_examples_files = Split('''
     serial_letter3.lyx
     simplecv.lyx
     splash.lyx
+    tufte-book.lyx
+    tufte-handout.lyx
     xyfigure.png
     xypic.lyx
 ''')
@@ -2404,6 +2445,7 @@ lib_examples_de_files = Split('''
     serienbrief2.lyx
     serienbrief3.lyx
     splash.lyx
+    tufte-handout.lyx
 ''')
 
 
@@ -2414,13 +2456,19 @@ lib_examples_fa_files = Split('''
 
 lib_examples_fr_files = Split('''
     AlignementDecimal.lyx
-    Foils.lyx
-    ListesPuces.lyx
+    Braille.lyx
     exemple_brut.lyx
     exemple_lyxifie.lyx
+    exemple-powerdot.lyx
+    Foils.lyx
+    linguistics.lyx
+    ListesPuces.lyx
     multicol.lyx
+    seminar.lyx
     simplecv.lyx
     splash.lyx
+    xyfigure.png
+    xypic.lyx
 ''')
 
 
@@ -2475,6 +2523,7 @@ lib_examples_it_files = Split('''
 
 
 lib_examples_ja_files = Split('''
+    Braille.lyx
     splash.lyx
 ''')
 
@@ -2508,6 +2557,11 @@ lib_examples_ru_files = Split('''
 ''')
 
 
+lib_examples_sk_files = Split('''
+    splash.lyx
+''')
+
+
 lib_examples_sl_files = Split('''
     primer_lyxan.lyx
     primer_surov.lyx
@@ -2521,8 +2575,8 @@ lib_examples_uk_files = Split('''
 
 
 lib_lyx2lyx_files = Split('''
-    LyX.py
     generate_encoding_info.py
+    LyX.py
     lyx2lyx
     lyx2lyx_lang.py
     lyx_0_06.py
@@ -2546,8 +2600,8 @@ lib_lyx2lyx_files = Split('''
 
 
 lib_lyx2lyx_extra_files = Split('''
-    Makefile.am
     lyx2lyx_version.py.in
+    Makefile.am
 ''')
 
 
@@ -2576,6 +2630,7 @@ lib_layouts_files = Split('''
     docbook-chapter.layout
     docbook-section.layout
     docbook.layout
+    doublecol-new.layout
     dtk.layout
     egs.layout
     elsart.layout
@@ -2613,7 +2668,6 @@ lib_layouts_files = Split('''
     literate-report.layout
     llncs.layout
     ltugboat.layout
-    manpage.layout
     memoir.layout
     moderncv.layout
     mwart.layout
@@ -2636,15 +2690,20 @@ lib_layouts_files = Split('''
     sigplanconf.layout
     simplecv.layout
     singlecol.layout
+    singlecol-new.layout
     slides.layout
     spie.layout
     svglobal.layout
     svglobal3.layout
     svjog.layout
+    svmono.layout
+    svmult.layout
     svprobth.layout
     tarticle.layout
     tbook.layout
     treport.layout
+    tufte-book.layout
+    tufte-handout.layout
 ''')
 
 
@@ -2689,6 +2748,8 @@ lib_layouts_inc_files = Split('''
     svjour.inc
     theorems.inc
     theorems-ams.inc
+    theorems-ams-bytype.inc
+    theorems-bytype.inc
     theorems-order.inc
     theorems-proof.inc
     theorems-starred.inc
@@ -2699,21 +2760,28 @@ lib_layouts_inc_files = Split('''
 lib_layouts_module_files = Split('''
     braille.module
     endnotes.module
+    eqs-within-sections.module
+    figs-within-sections.module
     foottoend.module
     hanging.module
     linguistics.module
     logicalmkup.module
     minimalistic.module
+    tabs-within-sections.module
+    theorems-ams-bytype.module
     theorems-ams-extended.module
+    theorems-ams-extended-bytype.module
     theorems-ams.module
+    theorems-bytype.module
+    theorems-chap-bytype.module
     theorems-chap.module
+    theorems-sec-bytype.module
     theorems-sec.module
     theorems-starred.module
     theorems-std.module
 ''')
 
 lib_scripts_files = Split('''
-    TeXFiles.py
     clean_dvi.py
     convertDefault.py
     csv2lyx.py
@@ -2729,6 +2797,7 @@ lib_scripts_files = Split('''
     lyxpreview2bitmap.py
     lyxpreview-platex2bitmap.py
     lyxpreview_tools.py
+    TeXFiles.py
     tex_copy.py
 ''')
 
