@@ -18,6 +18,7 @@
 #include "support/types.h"
 #include "support/SignalSlot.h"
 
+#include <set>
 #include <string>
 #include <vector>
 
@@ -126,9 +127,6 @@ public:
 	/// Maybe we know the function already by number...
 	bool dispatch(FuncRequest const & func, bool * result = 0);
 
-	/// Load the autosaved file.
-	void loadAutoSaveFile();
-
 	/// read a new document from a string
 	bool readString(std::string const &);
 	/// load a new file
@@ -163,6 +161,9 @@ public:
 
 	/// Write document to stream. Returns \c false if unsuccesful.
 	bool write(std::ostream &) const;
+	/// save emergency file
+	/// \return a status message towards the user.
+	docstring emergencyWrite();
 	/// Write file. Returns \c false if unsuccesful.
 	bool writeFile(support::FileName const &) const;
 
@@ -395,6 +396,10 @@ public:
 	/// Return macro defined before the inclusion of the child
 	MacroData const * getMacro(docstring const & name, Buffer const & child, bool global = true) const;
 
+	/// Collect user macro names at loading time
+	typedef std::set<docstring> UserMacroSet;
+	UserMacroSet usermacros;
+
 	/// Replace the inset contents for insets which InsetCode is equal
 	/// to the passed \p inset_code.
 	void changeRefsIfUnique(docstring const & from, docstring const & to,
@@ -447,6 +452,12 @@ public:
 
 	///
 	void autoSave() const;
+	///
+	void removeAutosaveFile() const;
+	///
+	void moveAutosaveFile(support::FileName const & old) const;
+	///
+	support::FileName getAutosaveFilename() const;
 
 	/// return the format of the buffer on a string
 	std::string bufferFormat() const;
