@@ -13,37 +13,42 @@
 #ifndef DEP_TABLE_H
 #define DEP_TABLE_H
 
+#include "support/FileName.h"
+
 #include <map>
 #include <string>
 
+
+namespace lyx {
+
 ///
 class DepTable {
 public:
 	/** This one is a little bit harder since we need the absolute
 	  filename. Should we insert files with .sty .cls etc as
 	  extension? */
-	void insert(std::string const & f, bool upd = false);
+	void insert(support::FileName const & f, bool upd = false);
 	///
 	void update();
 
 	///
-	void write(std::string const & f) const;
+	void write(support::FileName const & f) const;
 	/// returns true if dep file was read successfully
-	bool read(std::string const & f);
+	bool read(support::FileName const & f);
 	/// returns true if any of the files has changed
 	bool sumchange() const;
 	/// return true if fil has changed.
-	bool haschanged(std::string const & fil) const;
+	bool haschanged(support::FileName const & fil) const;
 	/// return true if a file with extension ext has changed.
 	bool extchanged(std::string const & ext) const;
 	///
-	bool exist(std::string const & fil) const;
+	bool exist(support::FileName const & fil) const;
 	/// returns true if any files with ext exist
 	bool ext_exist(std::string const & ext) const;
 	///
 	void remove_files_with_extension(std::string const &);
 	///
-	void remove_file(std::string const &);
+	void remove_file(support::FileName const &);
 private:
 	///
 	class dep_info {
@@ -58,9 +63,12 @@ private:
 		bool changed() const;
 	};
 	///
-	typedef std::map<std::string, dep_info> DepList;
+	typedef std::map<support::FileName, dep_info> DepList;
 	///
 	DepList deplist;
 };
 
+
+} // namespace lyx
+
 #endif
