@@ -18,6 +18,9 @@
 #include <string>
 
 
+namespace lyx {
+
+
 ///
 class FloatList {
 public:
@@ -48,4 +51,7 @@ private:
 	List list;
 };
 
+
+} // namespace lyx
+
 #endif
