@@ -4,7 +4,7 @@
  * Licence details can be found in the file COPYING.
  *
  * \author Alfredo Braunstein
- * \author André Pönitz
+ * \author Andr Pnitz
  *
  * Full author contact details are available in file CREDITS.
  */
@@ -13,7 +13,7 @@
 
 #include "InsetIterator.h"
 
-#include <boost/assert.hpp>
+#include "support/lassert.h"
 
 
 namespace lyx {
