@@ -189,7 +189,7 @@ private:
 				      std::vector<Aux_Info> const &);
 
 	///
-	bool runBibTeX(std::vector<Aux_Info> const &);
+	bool runBibTeX(std::vector<Aux_Info> const &, OutputParams const &);
 
 	///
 	void deleteFilesOnError() const;
