@@ -21,7 +21,7 @@
 #include "Buffer.h"
 #include "BufferList.h"
 #include "CmdDef.h"
-#include "Color.h"
+#include "ColorSet.h"
 #include "ConverterCache.h"
 #include "Converter.h"
 #include "CutAndPaste.h"
@@ -354,6 +354,9 @@ void LyX::prepareExit()
 	cap::clearCutStack();
 	cap::clearSelection();
 
+	// Write the index file of the converter cache
+	ConverterCache::get().writeIndex();
+
 	// close buffers first
 	pimpl_->buffer_list_.closeAll();
 
