@@ -11,49 +11,40 @@
 #include <config.h>
 
 #include "LyX.h"
-#include "debug.h"
-#include "support/lyxlib.h"
 
-#include <boost/assert.hpp>
+#include "support/debug.h"
+
+#include "support/lassert.h"
 
 #include <exception>
+#include <iomanip>
+#include <iostream>
 
-using std::endl;
+using namespace std;
 using lyx::lyxerr;
-using lyx::LyX;
 
 namespace boost {
 
 #ifndef BOOST_NO_EXCEPTIONS
 void throw_exception(std::exception const & e)
 {
-	lyxerr << "Exception caught:\n"
-	    << e.what() << endl;
-	BOOST_ASSERT(false);
+	lyxerr << "Exception caught:\n" << e.what() << endl;
+	LASSERT(false, /**/);
 }
 #endif
 
 
-void emergencyCleanup()
-{
-	static bool didCleanup;
-	if (didCleanup)
-		return;
-
-	didCleanup = true;
-
-	LyX::cref().emergencyCleanup();
-}
-
-
 void assertion_failed(char const * expr, char const * function,
 		      char const * file, long line)
 {
 	lyxerr << "Assertion triggered in " << function
 	       << " by failing check \"" << expr << "\""
 	       << " in file " << file << ":" << line << endl;
-	emergencyCleanup();
-	lyx::support::abort();
+
+	// FIXME: by default we exit here but we could also inform the user
+	// about the assertion and do the emergency cleanup without exiting.
+	// FIXME: do we have a list of exit codes defined somewhere?
+	lyx::lyx_exit(1);
 }
 
 } // namespace boost
