@@ -1,6 +1,6 @@
 // -*- C++ -*-
 /**
- * \file floatplacement.h
+ * \file FloatPlacement.h
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
@@ -10,16 +10,18 @@
  * Full author contact details are available in file CREDITS.
  */
 
-#ifndef QT_FLOATPLACEMENT_H
-#define QT_FLOATPLACEMENT_H
+#ifndef FLOATPLACEMENT_H
+#define FLOATPLACEMENT_H
 
-#include "ui/FloatPlacementUi.h"
+#include "ui_FloatPlacementUi.h"
 #include <QWidget>
 
 #include <string>
 
 
-namespace lyx { class InsetFloatParams; }
+namespace lyx {
+
+class InsetFloatParams;
 
 class FloatPlacement : public QWidget, public Ui::FloatPlacementUi {
 	Q_OBJECT
@@ -46,9 +48,12 @@ public Q_SLOTS:
 Q_SIGNALS:
 	void changed();
 
+private:
+	/// one of figure or table?
+	bool standardfloat_;
+
 };
 
+} // namespace lyx
 
-//} // namespace lyx
-
-#endif
+#endif // FLOATPLACEMENT_H
