@@ -58,9 +58,14 @@ static QString credits()
 			line = ts.readLine();
 			if (line.startsWith("@b"))
 				out << "<b>" << line.mid(2) << "</b>";
-			else if (line.startsWith("@i"))
+			else if (line.startsWith("@i")) {
+				if (line.startsWith("@iE-mail")) {
+					// unmask email
+					line.replace(QString(" () "), QString("@"));
+					line.replace(QString(" ! "), QString("."));
+				}
 				out << "<i>" << line.mid(2) << "</i>";
-			else
+			} else
 				out << line;
 			out << "<br>";
 		} while (!line.isNull());
@@ -94,11 +99,13 @@ static QString disclaimer()
 
 static QString version()
 {
-	QLocale loc;
-	QString loc_release_date =
-		loc.toString(release_date(), QLocale::LongFormat);
-	if (loc_release_date.isEmpty()) {
-		if (lyx_release_date == "not released yet")
+	QString loc_release_date;
+	QDate date = release_date();
+	if (date.isValid()) {
+		QLocale loc;
+		loc_release_date = loc.toString(date, QLocale::LongFormat);
+	} else {
+		if (QString(lyx_release_date) == "not released yet")
 			loc_release_date = qt_("not released yet");
 		else
 			loc_release_date = toqstr(lyx_release_date);
