@@ -390,7 +390,7 @@ PreviewLoader::Impl::Impl(PreviewLoader & p, Buffer const & b)
 	: parent_(p), buffer_(b), font_scaling_factor_(0.0)
 {
 	font_scaling_factor_ = 0.01 * lyxrc.dpi * lyxrc.zoom *
-		convert<double>(lyxrc.preview_scale_factor);
+		lyxrc.preview_scale_factor;
 
 	LYXERR(Debug::GRAPHICS, "The font scaling factor is "
 				<< font_scaling_factor_);
