@@ -130,7 +130,7 @@ string const doSubstitution(InsetExternalParams const & params,
 				    relToParentPath, use_latex_path,
 				    PROTECT_EXTENSION,
 				    ESCAPE_DOTS);
-		if (FileName(filename).isAbsolute()) {
+		if (FileName::isAbsolute(filename)) {
 			result = subst_path(result, "$$AbsOrRelPathMaster",
 					    abspath, use_latex_path,
 					    PROTECT_EXTENSION,
@@ -296,7 +296,9 @@ void updateExternal(InsetExternalParams const & params,
 						      ALL_BUT_PATHS);
 				// if file is a relative name, it is interpreted
 				// relative to the master document.
-				exportdata.addExternalFile(rit->first, source, file);
+				if (makeAbsPath(file, masterBuffer->filePath()) !=
+					params.filename.absFilename())
+						exportdata.addExternalFile(rit->first, source, file);
 			}
 		}
 	}
