@@ -47,7 +47,7 @@ private:
 	void cursorPos(BufferView const & bv,
 		CursorSlice const & sl, bool boundary, int & x, int & y) const;
 	///
-	bool descendable() const { return true; }
+	bool descendable(BufferView const &) const { return true; }
 	///
 	void metrics(MetricsInfo & mi, Dimension & dim) const;
 	///
