@@ -79,7 +79,7 @@ public:
 	///
 	EDITABLE editable() const;
 	/// can we go further down on mouse click?
-	bool descendable() const;
+	bool descendable(BufferView const & bv) const;
 	///
 	void setLabel(docstring const & l);
 	///
@@ -180,6 +180,12 @@ private:
 	///
 	Dimension dimensionCollapsed(BufferView const & bv) const;
 	///
+	/// should paragraphs be forced to use the empty layout?
+	virtual bool forcePlainLayout(idx_type = 0) const 
+		{ return getLayout().forcePlainLayout(); }
+	/// should the user be allowed to customize alignment, etc.?
+	virtual bool allowParagraphCustomization(idx_type = 0) const 
+		{ return getLayout().allowParagraphCustomization(); }
 	docstring labelstring_;
 	///
 	mutable Box button_dim;
