@@ -27,33 +27,36 @@ public:
 	///
 	InsetFloatList(std::string const & type);
 	///
-	docstring const getScreenLabel(Buffer const &) const;
+	docstring screenLabel() const;
 	///
 	EDITABLE editable() const { return IS_EDITABLE; }
 	///
-	Inset::Code lyxCode() const;
+	InsetCode lyxCode() const { return FLOAT_LIST_CODE; }
 	///
 	DisplayType display() const { return AlignCenter; }
 	///
-	void write(Buffer const &, std::ostream &) const;
+	void write(std::ostream &) const;
 	///
-	void read(Buffer const &, Lexer &);
+	void read(Lexer &);
 	///
-	int latex(Buffer const &, odocstream &,
-		  OutputParams const &) const;
+	int latex(odocstream &, OutputParams const &) const;
 	///
-	int docbook(Buffer const &, odocstream &,
-		    OutputParams const &) const { return 0; }
+	int docbook(odocstream &, OutputParams const &) const { return 0; }
 	///
-	int plaintext(Buffer const &, odocstream &,
-		      OutputParams const & runparams) const;
+	int plaintext(odocstream &, OutputParams const & runparams) const;
 	///
 	void validate(LaTeXFeatures & features) const;
+	///
+	static ParamInfo const & findInfo(std::string const &);
+	///
+	static std::string defaultCommand() { return "listoftables"; };
+	///
+	static bool isCompatibleCommand(std::string const & s);
 private:
-	virtual std::auto_ptr<Inset> doClone() const
-	{
-		return std::auto_ptr<Inset>(new InsetFloatList(to_ascii(getParam("type"))));
-	}
+	///
+	Inset * clone() const { return new InsetFloatList(*this); }
+	///
+	static ParamInfo param_info_;
 };
 
 
