@@ -82,7 +82,7 @@ docstring InsetFoot::toolTip(BufferView const & bv, int x, int y) const
 {
 	docstring default_tip = InsetCollapsable::toolTip(bv, x, y);
 	if (!isOpen(bv))
-		return custom_label_ + ": " + default_tip;
+		return custom_label_ + "\n" + default_tip;
 	return default_tip;
 }
 
