@@ -23,24 +23,21 @@ public:
 
 	InsetLine() {}
 
-	Inset::Code lyxCode() const { return Inset::LINE_CODE; }
+	InsetCode lyxCode() const { return LINE_CODE; }
 
-	bool metrics(MetricsInfo &, Dimension &) const;
+	void metrics(MetricsInfo &, Dimension &) const;
 
 	void draw(PainterInfo & pi, int x, int y) const;
 
-	int latex(Buffer const &, odocstream &,
-		  OutputParams const &) const;
+	int latex(odocstream &, OutputParams const &) const;
 
-	int plaintext(Buffer const &, odocstream &,
-		      OutputParams const &) const;
+	int plaintext(odocstream &, OutputParams const &) const;
 
-	int docbook(Buffer const &, odocstream &,
-		    OutputParams const &) const;
+	int docbook(odocstream &, OutputParams const &) const;
 
-	void read(Buffer const &, Lexer & lex);
+	void read(Lexer & lex);
 
-	void write(Buffer const & buf, std::ostream & os) const;
+	void write(std::ostream & os) const;
 	/// We don't need \begin_inset and \end_inset
 	bool directWrite() const { return true; }
 
@@ -48,10 +45,7 @@ public:
 	///
 	void validate(LaTeXFeatures & features) const;
 private:
-	virtual std::auto_ptr<Inset> doClone() const
-	{
-		return std::auto_ptr<Inset>(new InsetLine);
-	}
+	Inset * clone() const { return new InsetLine(*this); }
 };
 
 
