@@ -801,7 +801,7 @@ public:
 	///
 	Inset * editXY(Cursor & cur, int x, int y);
 	/// can we go further down on mouse click?
-	bool descendable() const { return true; }
+	bool descendable(BufferView const &) const { return true; }
 	// Update the counters of this inset and of its contents
 	void updateLabels(ParIterator const &);
 
