@@ -11,32 +11,30 @@
 
 #include <config.h>
 
-#include "debug.h"
 #include "LyX.h"
-#include "gettext.h"
 
+#include "support/debug.h"
+#include "support/gettext.h"
 #include "support/os.h"
 
-#include <boost/filesystem/path.hpp>
-
+#include <iostream>
 #ifdef HAVE_IOS
 #include <ios>
 #endif
 
+using namespace std;
 
-namespace fs = boost::filesystem;
 
 int main(int argc, char * argv[])
 {
 #ifdef HAVE_IOS
-	std::ios_base::sync_with_stdio(false);
+	ios_base::sync_with_stdio(false);
 #endif
-	fs::path::default_name_check(fs::no_check);
 
 	// To avoid ordering of global object problems with some
 	// stdlibs we do the initialization here, but still as
 	// early as possible.
-	lyx::lyxerr.rdbuf(std::cerr.rdbuf());
+	lyx::lyxerr.setStream(cerr);
 
 	lyx::support::os::init(argc, argv);
 
