@@ -24,13 +24,13 @@ class latexkeys;
 class InsetMathFontOld : public InsetMathNest {
 public:
 	///
-	explicit InsetMathFontOld(latexkeys const * key);
+	explicit InsetMathFontOld(Buffer * buf, latexkeys const * key);
 	/// we are in text mode.
 	mode_type currentMode() const { return TEXT_MODE; }
 	/// we write extra braces in any case...
 	bool extraBraces() const { return true; }
 	///
-	bool metrics(MetricsInfo & mi, Dimension & dim) const;
+	void metrics(MetricsInfo & mi, Dimension & dim) const;
 	///
 	void draw(PainterInfo & pi, int x, int y) const;
 	///
@@ -44,10 +44,10 @@ public:
 	///
 	void infoize(odocstream & os) const;
 	///
-	int kerning() const { return cell(0).kerning(); }
+	int kerning(BufferView const * bv) const { return cell(0).kerning(bv); }
 
 private:
-	virtual std::auto_ptr<Inset> doClone() const;
+	virtual Inset * clone() const;
 	/// the font to be used on screen
 	latexkeys const * key_;
 };
