@@ -14,19 +14,19 @@
 
 #include "InsetMath.h"
 
+#include "support/docstring.h"
+
 
 namespace lyx {
 
-
-/** Some inset that "is" a number
- *  mainly for math-extern
+/** Some inset that "is" a number mainly for math-extern
  */
 class InsetMathNumber : public InsetMath {
 public:
 	///
 	explicit InsetMathNumber(docstring const & s);
 	///
-	bool metrics(MetricsInfo & mi, Dimension & dim) const;
+	void metrics(MetricsInfo & mi, Dimension & dim) const;
 	///
 	void draw(PainterInfo &, int x, int y) const;
 	///
@@ -48,11 +48,12 @@ public:
 	void write(WriteStream & os) const;
 
 private:
-	virtual std::auto_ptr<Inset> doClone() const;
+	virtual Inset * clone() const;
 	/// the number as string
 	docstring str_;
 };
 
 
 } // namespace lyx
+
 #endif
