@@ -25,11 +25,11 @@ namespace lyx {
 class InsetMathScript : public InsetMathNest {
 public:
 	/// create inset without scripts
-	InsetMathScript();
+	InsetMathScript(Buffer * buf);
 	/// create inset with single script
-	explicit InsetMathScript(bool up);
+	explicit InsetMathScript(Buffer * buf, bool up);
 	/// create inset with single script and given nucleus
-	InsetMathScript(MathAtom const & at, bool up);
+	InsetMathScript(Buffer * buf, MathAtom const & at, bool up);
 	///
 	mode_type currentMode() const { return MATH_MODE; }
 	///
