@@ -13,7 +13,7 @@
 #define MATH_UNDERSETINSET_H
 
 
-#include "InsetMathFracBase.h"
+#include "InsetMathFrac.h"
 
 
 namespace lyx {
@@ -22,7 +22,9 @@ namespace lyx {
 class InsetMathUnderset : public InsetMathFracBase {
 public:
 	///
-	bool metrics(MetricsInfo & mi, Dimension & dim) const;
+	InsetMathUnderset(Buffer * buf) : InsetMathFracBase(buf) {}
+	///
+	void metrics(MetricsInfo & mi, Dimension & dim) const;
 	///
 	void draw(PainterInfo & pi, int x, int y) const;
 	///
@@ -38,7 +40,7 @@ public:
 	///
 	void validate(LaTeXFeatures & features) const;
 private:
-	virtual std::auto_ptr<Inset> doClone() const;
+	virtual Inset * clone() const;
 };
 
 
