@@ -256,14 +256,20 @@ TeXEnvironment(Buffer const & buf,
 		os << "\\end{" << from_ascii(style.latexname()) << "}\n";
 		texrow.newline();
 		prev_env_language_ = par_language;
-		runparams.encoding = prev_encoding;
+		if (runparams.encoding != prev_encoding) {
+			runparams.encoding = prev_encoding;
+			os << setEncoding(prev_encoding->iconvName());
+		}
 	}
 
 	if (leftindent_open) {
 		os << "\\end{LyXParagraphLeftIndent}\n";
 		texrow.newline();
 		prev_env_language_ = par_language;
-		runparams.encoding = prev_encoding;
+		if (runparams.encoding != prev_encoding) {
+			runparams.encoding = prev_encoding;
+			os << setEncoding(prev_encoding->iconvName());
+		}
 	}
 
 	if (par != paragraphs.end())
@@ -596,7 +602,10 @@ TeXOnePar(Buffer const & buf,
 		os << "\\par}";
 	} else if (is_command) {
 		os << '}';
-		runparams.encoding = prev_encoding;
+		if (runparams.encoding != prev_encoding) {
+			runparams.encoding = prev_encoding;
+			os << setEncoding(prev_encoding->iconvName());
+		}
 	}
 
 	bool pending_newline = false;
@@ -666,11 +675,18 @@ TeXOnePar(Buffer const & buf,
 		// when the paragraph uses CJK, the language has to be closed earlier
 		if (font.language()->encoding()->package() != Encoding::CJK) {
 			if (lyxrc.language_command_end.empty()) {
-				if (!prev_language->babel().empty()) {
+				// If this is a child, we should restore the
+				// master language after the last paragraph.
+				Language const * const current_language =
+					(nextpit == paragraphs.end()
+					 && runparams.master_language)
+						? runparams.master_language
+						: prev_language;
+				if (!current_language->babel().empty()) {
 					os << from_ascii(subst(
 						lyxrc.language_command_begin,
 						"$$lang",
-						prev_language->babel()));
+						current_language->babel()));
 					pending_newline = true;
 				}
 			} else if (!par_language->babel().empty()) {
