@@ -13,15 +13,17 @@
 #ifndef LYX_DOCSTRING_H
 #define LYX_DOCSTRING_H
 
-#include "support/types.h"
+#include "support/strfwd.h"
 
-#include <cstring>
 #include <string>
-#include <typeinfo>
 
 namespace lyx {
 
-/// String type for storing the main text in UCS4 encoding
+/**
+ * String type for storing the main text in UCS4 encoding.
+ * Use std::string only in cases 7-bit ASCII is to be manipulated
+ * within the variable.
+ */
 typedef std::basic_string<char_type> docstring;
 
 /// Creates a docstring from a C string of ASCII characters
@@ -42,14 +44,6 @@ std::string const to_utf8(docstring const &);
 /// convert \p s from the encoding of the locale to ucs4.
 docstring const from_local8bit(std::string const & s);
 
-/// Exception thrown by to_local8bit if the string could not be converted
-class to_local8bit_failure : public std::bad_cast {
-public:
-	to_local8bit_failure() throw() : std::bad_cast() {}
-	virtual ~to_local8bit_failure() throw() {}
-	virtual const char* what() const throw();
-};
-
 /**
  * Convert \p s from ucs4 to the encoding of the locale.
  * This may fail and throw an exception, the caller is expected to act
@@ -67,34 +61,34 @@ std::string const to_filesystem8bit(docstring const & s);
 docstring const normalize_c(docstring const & s);
 
 /// Compare a docstring with a C string of ASCII characters
-bool operator==(lyx::docstring const &, char const *);
+bool operator==(docstring const &, char const *);
 
 /// Compare a C string of ASCII characters with a docstring
-inline bool operator==(char const * l, lyx::docstring const & r) { return r == l; }
+inline bool operator==(char const * l, docstring const & r) { return r == l; }
 
 /// Compare a docstring with a C string of ASCII characters
-inline bool operator!=(lyx::docstring const & l, char const * r) { return !(l == r); }
+inline bool operator!=(docstring const & l, char const * r) { return !(l == r); }
 
 /// Compare a C string of ASCII characters with a docstring
-inline bool operator!=(char const * l, lyx::docstring const & r) { return !(r == l); }
+inline bool operator!=(char const * l, docstring const & r) { return !(r == l); }
 
 /// Concatenate a docstring and a C string of ASCII characters
-lyx::docstring operator+(lyx::docstring const &, char const *);
+docstring operator+(docstring const &, char const *);
 
 /// Concatenate a C string of ASCII characters and a docstring
-lyx::docstring operator+(char const *, lyx::docstring const &);
+docstring operator+(char const *, docstring const &);
 
 /// Concatenate a docstring and a single ASCII character
-lyx::docstring operator+(lyx::docstring const & l, char r);
+docstring operator+(docstring const & l, char r);
 
 /// Concatenate a single ASCII character and a docstring
-lyx::docstring operator+(char l, lyx::docstring const & r);
+docstring operator+(char l, docstring const & r);
 
 /// Append a C string of ASCII characters to a docstring
-lyx::docstring & operator+=(lyx::docstring &, char const *);
+docstring & operator+=(docstring &, char const *);
 
 /// Append a single ASCII character to a docstring
-lyx::docstring & operator+=(lyx::docstring & l, char r);
+docstring & operator+=(docstring & l, char r);
 
 } // namespace lyx
 
