@@ -11,19 +11,18 @@
 #include <config.h>
 
 #include "support/lyxtime.h"
-#include "LyXRC.h"
 
-using std::string;
+using namespace std;
 
 namespace lyx {
 
-time_type current_time()
+time_t current_time()
 {
 	return time(0);
 }
 
 
-string const formatted_time(time_type t, string const & fmt)
+string const formatted_time(time_t t, string const & fmt)
 {
 	struct tm * loc_tm = localtime(&t);
 	char date[50];
@@ -31,10 +30,4 @@ string const formatted_time(time_type t, string const & fmt)
 	return string(date);
 }
 
-
-string const formatted_time(time_type t)
-{
-	return formatted_time(t, lyxrc.date_insert_format);
-}
-
 } // namespace lyx
