@@ -19,21 +19,13 @@
 
 namespace lyx {
 
-typedef time_t time_type;
-
-time_type current_time();
+time_t current_time();
 
 /** Returns a locale-dependent formatting of the date
  * and time encoded in \c time. The \p fmt string
  *  holds the formatting arguments of \c strftime.
  */
-std::string const formatted_time(time_type t, std::string const & fmt);
-
-/** Returns a locale-dependent formatting of the date
- * and time encoded in \c time. For the formatting,
- *  \c lyxrc.date_insert_format is being used.
- */
-std::string const formatted_time(time_type t);
+std::string const formatted_time(time_t t, std::string const & fmt);
 
 }; // namespace lyx
 
