@@ -11,22 +11,22 @@
 #include <config.h>
 
 #if defined(__CYGWIN__) || defined(__CYGWIN32__)
-#include "os_cygwin.cpp"
+#include "support/os_cygwin.cpp"
 #elif defined(_WIN32)
-#include "os_win32.cpp"
+#include "support/os_win32.cpp"
 #else
-#include "os_unix.cpp"
+#include "support/os_unix.cpp"
 #endif
 
 namespace lyx {
 namespace support {
 namespace os {
 
-std::string const python()
+string const python()
 {
 	// Use the -tt switch so that mixed tab/whitespace indentation is
 	// an error
-	static std::string const command("python -tt");
+	static string const command("python -tt");
 	return command;
 }
 
