@@ -39,6 +39,9 @@ int accept(int)
 
 #include "support/debug.h"
 
+#ifdef HAVE_SYS_TYPES_H
+# include <sys/types.h>
+#endif
 #include <sys/socket.h>
 #include <sys/un.h>
 #include <fcntl.h>
