@@ -11,13 +11,15 @@
 
 #include <config.h>
 
-#include "gettext.h"
+#include "support/gettext.h"
+#include "../support/docstring.h"
 
+using namespace std;
 
 namespace lyx {
 
 
-docstring const _(std::string const & str)
+docstring const _(string const & str)
 {
 	return from_ascii(str);
 }
